@@ -32,6 +32,7 @@
  * still be added to a #SoupSession, but libsoup will never attempt to
  * actually use this auth type.
  *
+ * Returns: %TRUE if supported otherwise %FALSE
  */
 gboolean
 soup_auth_negotiate_supported (void)
@@ -361,9 +362,20 @@ check_server_response (SoupMessage *msg, gpointer auth)
 	auth_headers = soup_message_headers_get_one_common (soup_message_get_response_headers (msg),
                                                             SOUP_HEADER_WWW_AUTHENTICATE);
 	if (!auth_headers || g_ascii_strncasecmp (auth_headers, "Negotiate ", 10) != 0) {
-		g_warning ("Failed to parse auth header");
+		if (soup_message_get_status (msg) == SOUP_STATUS_OK) {
+			/* The server *may* supply final authentication data to
+			 * the client, but doesn't have to. We are not
+			 * authenticating the server, so just ignore missing
+			 * auth data. In practice, this is required for web
+			 * compat.
+			 */
+		        priv->is_authenticated = TRUE;
+		        return;
+		}
+
+		g_warning ("Server bug: missing or invalid WWW-Authenticate header: %s", auth_headers);
 		conn->state = SOUP_NEGOTIATE_FAILED;
-		goto out;
+		return;
 	}
 
 	ret = soup_gss_client_step (conn, auth_headers + 10, &error_message);
@@ -393,7 +405,7 @@ check_server_response (SoupMessage *msg, gpointer auth)
 	default:
 		conn->state = SOUP_NEGOTIATE_FAILED;
 	}
- out:
+
 	g_clear_pointer (&error_message, g_free);
 }
 
@@ -584,7 +596,7 @@ soup_gss_client_step (SoupNegotiateConnectionState *conn, const gchar *challenge
 					 &conn->context,
 					 conn->server_name,
 					 (gss_OID) &gss_mech_spnego,
-					 GSS_C_MUTUAL_FLAG,
+					 0,
 					 GSS_C_INDEFINITE,
 					 GSS_C_NO_CHANNEL_BINDINGS,
 					 &in,
