@@ -12,6 +12,7 @@
 #include <string.h>
 
 #include "soup-auth-domain-basic.h"
+#include "soup-auth-domain-private.h"
 #include "soup-message-headers-private.h"
 #include "soup.h"
 
@@ -50,7 +51,7 @@ typedef struct {
 	GDestroyNotify auth_dnotify;
 } SoupAuthDomainBasicPrivate;
 
-G_DEFINE_TYPE_WITH_PRIVATE (SoupAuthDomainBasic, soup_auth_domain_basic, SOUP_TYPE_AUTH_DOMAIN)
+G_DEFINE_FINAL_TYPE_WITH_PRIVATE (SoupAuthDomainBasic, soup_auth_domain_basic, SOUP_TYPE_AUTH_DOMAIN)
 
 static void
 soup_auth_domain_basic_init (SoupAuthDomainBasic *basic)
@@ -114,7 +115,7 @@ soup_auth_domain_basic_get_property (GObject *object, guint prop_id,
 }
 
 /**
- * soup_auth_domain_basic_new:
+ * soup_auth_domain_basic_new: (constructor)
  * @optname1: name of first option, or %NULL
  * @...: option name/value pairs
  *
