@@ -28,6 +28,9 @@ GInputStream *soup_session_setup_message_body_input_stream (SoupSession        *
                                                             GInputStream       *body_stream,
                                                             SoupProcessingStage start_at_stage);
 
+GSList       *soup_session_get_features                    (SoupSession        *session,
+							    GType               feature_type);
+
 G_END_DECLS
 
 #endif /* __SOUP_SESSION_PRIVATE_H__ */
