@@ -6,7 +6,7 @@
 #include "test-utils.h"
 
 #include "soup-connection.h"
-#include "soup-server-connection.h"
+#include "soup-socket.h"
 #include "soup-server-message-private.h"
 
 #include <gio/gnetworking.h>
@@ -24,17 +24,17 @@ forget_close (SoupServerMessage *msg,
 }
 
 static void
-close_socket (SoupServerMessage    *msg,
-	      SoupServerConnection *conn)
+close_socket (SoupServerMessage *msg,
+	      SoupSocket        *sock)
 {
-        GSocket *socket;
+        GSocket *gsocket;
 	int sockfd;
 
 	/* Actually calling soup_socket_disconnect() here would cause
 	 * us to leak memory, so just shutdown the socket instead.
 	 */
-        socket = soup_server_connection_get_socket (conn);
-	sockfd = g_socket_get_fd (socket);
+        gsocket = soup_socket_get_gsocket (sock); 
+	sockfd = g_socket_get_fd (gsocket);
 #ifdef G_OS_WIN32
 	shutdown (sockfd, SD_SEND);
 #else
@@ -50,42 +50,41 @@ close_socket (SoupServerMessage    *msg,
 }
 
 static gboolean
-timeout_socket (GObject              *pollable,
-		SoupServerConnection *conn)
+timeout_socket (GObject    *pollable,
+		SoupSocket *sock)
 {
-	soup_server_connection_disconnect (conn);
+	soup_socket_disconnect (sock);
 	return FALSE;
 }
 
 static void
-timeout_request_finished (SoupServer        *server,
-                          SoupServerMessage *msg,
-                          gpointer           user_data)
+timeout_request_started (SoupServer        *server,
+			 SoupServerMessage *msg,
+			 gpointer           user_data)
 {
-	SoupServerConnection *conn;
+	SoupSocket *sock;
 	GMainContext *context = g_main_context_get_thread_default ();
 	GIOStream *iostream;
 	GInputStream *istream;
 	GSource *source;
 
-	g_signal_handlers_disconnect_by_func (server, timeout_request_finished, NULL);
+	g_signal_handlers_disconnect_by_func (server, timeout_request_started, NULL);
 
-	conn = soup_server_message_get_connection (msg);
-	iostream = soup_server_connection_get_iostream (conn);
+	sock = soup_server_message_get_soup_socket (msg);
+	iostream = soup_socket_get_iostream (sock);
 	istream = g_io_stream_get_input_stream (iostream);
 	source = g_pollable_input_stream_create_source (G_POLLABLE_INPUT_STREAM (istream), NULL);
-	g_source_set_callback (source, (GSourceFunc)timeout_socket, conn, NULL);
+	g_source_set_callback (source, (GSourceFunc)timeout_socket, sock, NULL);
 	g_source_attach (source, g_main_context_get_thread_default ());
 	g_source_unref (source);
 
 	g_mutex_unlock (&server_mutex);
-	while (soup_server_connection_is_connected (conn))
+	while (soup_socket_is_connected (sock))
 		g_main_context_iteration (context, TRUE);
 }
 
 static void
-setup_timeout_persistent (SoupServer           *server,
-                          SoupServerConnection *conn)
+setup_timeout_persistent (SoupServer *server, SoupSocket *sock)
 {
 	/* In order for the test to work correctly, we have to
 	 * close the connection *after* the client side writes
@@ -102,8 +101,8 @@ setup_timeout_persistent (SoupServer           *server,
 	 *   3. Close the socket.
 	 */
 	g_mutex_lock (&server_mutex);
-	g_signal_connect (server, "request-finished",
-			  G_CALLBACK (timeout_request_finished), NULL);
+	g_signal_connect (server, "request-started",
+			  G_CALLBACK (timeout_request_started), NULL);
 }
 
 static void
@@ -144,16 +143,16 @@ server_callback (SoupServer        *server,
 					     "Connection", "close");
 
 		if (too_long) {
-			SoupServerConnection *conn;
+			SoupSocket *sock;
 
 			/* soup-message-io will wait for us to add
 			 * another chunk after the first, to fill out
 			 * the declared Content-Length. Instead, we
 			 * forcibly close the socket at that point.
 			 */
-			conn = soup_server_message_get_connection (msg);
+			sock = soup_server_message_get_soup_socket (msg);
 			g_signal_connect (msg, "wrote-chunk",
-					  G_CALLBACK (close_socket), conn);
+					  G_CALLBACK (close_socket), sock);
 		} else if (no_close) {
 			/* Remove the 'Connection: close' after writing
 			 * the headers, so that when we check it after
@@ -167,10 +166,10 @@ server_callback (SoupServer        *server,
 	}
 
 	if (!strcmp (path, "/timeout-persistent")) {
-		SoupServerConnection *conn;
+		SoupSocket *sock;
 
-		conn = soup_server_message_get_connection (msg);
-		setup_timeout_persistent (server, conn);
+		sock = soup_server_message_get_soup_socket (msg);
+		setup_timeout_persistent (server, sock);
 	}
 
 	soup_server_message_set_status (msg, SOUP_STATUS_OK, NULL);
@@ -1646,45 +1645,6 @@ do_connection_force_http2_test (void)
         soup_test_session_abort_unref (session);
 }
 
-static void
-message_restarted (SoupMessage *msg,
-                   gboolean    *was_restarted)
-{
-        *was_restarted = TRUE;
-}
-
-static void
-do_connection_http_1_1_required_test (void)
-{
-        SoupSession *session;
-        SoupMessage *msg;
-        GBytes *body;
-        gboolean was_restarted = FALSE;
-        GError *error = NULL;
-
-        SOUP_TEST_SKIP_IF_NO_TLS;
-        SOUP_TEST_SKIP_IF_NO_APACHE;
-
-        session = soup_test_session_new (NULL);
-
-        msg = soup_message_new ("GET", "https://127.0.0.1:47525/client-cert");
-        soup_message_set_force_http_version (msg, SOUP_HTTP_2_0);
-        g_signal_connect (msg, "restarted",
-                          G_CALLBACK (message_restarted), &was_restarted);
-        body = soup_test_session_async_send (session, msg, NULL, &error);
-        g_assert_no_error (error);
-        g_assert_cmpuint (soup_message_get_status (msg), ==, 403);
-        g_assert_true (was_restarted);
-        g_assert_nonnull (body);
-        g_bytes_unref (body);
-        g_object_unref (msg);
-
-        while (g_main_context_pending (NULL))
-                g_main_context_iteration (NULL, FALSE);
-
-        soup_test_session_abort_unref (session);
-}
-
 int
 main (int argc, char **argv)
 {
@@ -1709,7 +1669,6 @@ main (int argc, char **argv)
 	g_test_add_func ("/connection/preconnect", do_connection_preconnect_test);
         g_test_add_func ("/connection/metrics", do_connection_metrics_test);
         g_test_add_func ("/connection/force-http2", do_connection_force_http2_test);
-        g_test_add_func ("/connection/http2/http-1-1-required", do_connection_http_1_1_required_test);
 
 	ret = g_test_run ();
 
