@@ -14,6 +14,7 @@
 
 #ifdef HAVE_APACHE
 static gboolean apache_running;
+static char *server_root = NULL;
 #endif
 
 static SoupLogger *logger;
@@ -164,14 +165,19 @@ static gboolean
 apache_cmd (const char *cmd)
 {
 	GPtrArray *argv;
-	char *server_root, *cwd, *pid_file;
+	char *cwd, *pid_file;
 #ifdef HAVE_APACHE_2_4
 	char *default_runtime_dir;
 #endif
 	int status;
 	gboolean ok;
+	GString *str;
+	guint i;
 
-	server_root = soup_test_build_filename_abs (G_TEST_BUILT, "", NULL);
+	if (server_root == NULL) {
+		g_test_message ("Server root not initialized");
+		return FALSE;
+	}
 
 	cwd = g_get_current_dir ();
 #ifdef HAVE_APACHE_2_4
@@ -197,12 +203,23 @@ apache_cmd (const char *cmd)
 	g_ptr_array_add (argv, (char *)cmd);
 	g_ptr_array_add (argv, NULL);
 
+	str = g_string_new ("Apache command:");
+
+	for (i = 0; i < argv->len - 1; i++) {
+		char *escaped = g_shell_quote (argv->pdata[i]);
+		g_string_append_c (str, ' ');
+		g_string_append (str, escaped);
+		g_free (escaped);
+	}
+
+	g_test_message ("%s", str->str);
+	g_string_free (str, TRUE);
+
 	ok = g_spawn_sync (cwd, (char **)argv->pdata, NULL, 0, NULL, NULL,
 			   NULL, NULL, &status, NULL);
 	if (ok)
 		ok = (status == 0);
 
-	g_free (server_root);
 	g_free (cwd);
 	g_free (pid_file);
 #ifdef HAVE_APACHE_2_4
@@ -210,6 +227,7 @@ apache_cmd (const char *cmd)
 #endif
 	g_ptr_array_free (argv, TRUE);
 
+	g_test_message (ok ? "-> success" : "-> failed");
 	return ok;
 }
 
@@ -221,6 +239,8 @@ apache_init (void)
 	if (g_getenv ("SOUP_TESTS_ALREADY_RUNNING_APACHE"))
 		return;
 
+	server_root = soup_test_build_filename_abs (G_TEST_BUILT, "", NULL);
+
 	if (!apache_cmd ("start")) {
 		g_printerr ("Could not start apache\n");
 		exit (1);
@@ -248,6 +268,8 @@ apache_cleanup (void)
 		while (kill (pid, 0) == 0)
 			g_usleep (100);
 	}
+
+	g_clear_pointer (&server_root, g_free);
 }
 
 #endif /* HAVE_APACHE */
